
package com.madhu.xml;

import java.io.*;
import org.xml.sax.*;
import org.xml.sax.helpers.*;

public class SAXErrors extends DefaultHandler {
	private Locator locator;

	public void startDocument() {
		System.out.println("***Start of Document***");
	}

	public void endDocument() {
		System.out.println("***End of Document***");
	}

	public void setDocumentLocator(Locator inLocator) {
		System.out.println("***Got Locator***");
		locator = inLocator;
		int line = locator.getLineNumber();
		int column = locator.getColumnNumber();
		String publicID = locator.getPublicId();
		String systemID = locator.getSystemId();

		System.out.println("Line " + line + ", column " + column);
		if (publicID != null) {
			System.out.println("Public ID " + publicID);
		}
		if (systemID != null) {
			System.out.println("System ID " + systemID);
		}
	}

	public void printLocation(SAXParseException e) {
		int line = e.getLineNumber();
		int column = e.getColumnNumber();
		String publicID = e.getPublicId();
		String systemID = e.getSystemId();

		System.out.println("Line " + line + ", column " + column);
		if (publicID != null) {
			System.out.println("Public ID " + publicID);
		}
		if (systemID != null) {
			System.out.println("System ID " + systemID);
		}
	}

	public void error(SAXParseException e) {
		printLocation(e);
		System.out.println("Recoverable error: " + e.getMessage());
		Exception ex = e.getException();
		if (ex != null) {
			System.out.println("Embedded exception: " + ex.getMessage());
		}
	}

	public void fatalError(SAXParseException e) {
		printLocation(e);
		System.out.println("Non-recoverable error: " + e.getMessage());
		Exception ex = e.getException();
		if (ex != null) {
			System.out.println("Embedded exception: " + ex.getMessage());
		}
	}

	public void warning(SAXParseException e) {
		printLocation(e);
		System.out.println("Warning: " + e.getMessage());
		Exception ex = e.getException();
		if (ex != null) {
			System.out.println("Embedded exception: " + ex.getMessage());
		}
	}

	public static void main(String args[]) throws Exception {
		if (args.length != 1) {
			System.err.println("Usage: java SAXErrors <xml-file>");
			System.exit(1);
		}

		XMLReader parser = XMLReaderFactory.createXMLReader(
			"org.apache.xerces.parsers.SAXParser");

		parser.setFeature("http://xml.org/sax/features/validation", true);

		SAXErrors handler = new SAXErrors();
		parser.setContentHandler(handler);
		parser.setErrorHandler(handler);

		parser.parse(new InputSource(new FileReader(args[0])));
	}
}
