
package com.madhu.xml;

import java.io.*;
import org.xml.sax.*;
import org.xml.sax.ext.*;
import org.xml.sax.helpers.*;

public class SAXLexical extends DefaultHandler implements LexicalHandler {
	public SAXLexical() {
	}

	public void startDocument() {
		System.out.println("***Start of Document***");
	}

	public void endDocument() {
		System.out.println("***End of Document***");
	}

	public void startElement(String uri, String localName,
		String qName, Attributes attributes) {

		System.out.print("<" + qName);
		int n = attributes.getLength();
		for (int i=0; i<n; i+=1) {
			System.out.print(" " + attributes.getQName(i) +
				"='" + attributes.getValue(i) + "'");
		}
		System.out.println(">");
	}

	public void characters(char[] ch, int start, int length) {
		System.out.println(new String(ch, start, length).trim());
	}

	public void endElement(String namespaceURI, String localName,
		String qName) throws SAXException {

		System.out.println("</" + qName + ">");
	}

	public void startDTD(String name, String publicId,
		String systemId) throws SAXException {

		System.out.print("*** Start DTD, name " + name);
		if (publicId != null) {
			System.out.print(" PUBLIC " + publicId);
		}
		if (systemId != null) {
			System.out.print(" SYSTEM " + systemId);
		}
		System.out.println(" ***");
	}

	public void endDTD() throws SAXException {
		System.out.println("*** End DTD ***");
	}

	public void startEntity(String name) throws SAXException {
		System.out.println("*** Start Entity " + name + " ***");
	}

	public void endEntity(String name) throws SAXException {
		System.out.println("*** End Entity " + name + " ***");
	}

	public void startCDATA() throws SAXException {
		System.out.println("*** Start CDATA ***");
	}

	public void endCDATA() throws SAXException {
		System.out.println("*** End CDATA ***");
	}

	public void comment(char[] ch, int start, int length)
		throws SAXException {

		System.out.println("<!-- " +
			new String(ch, start, length) + " -->");
	}

	public static void main(String args[]) throws Exception {
		if (args.length != 1) {
			System.err.println("Usage: java SAXLexical <xml-file>");
			System.exit(1);
		}

		XMLReader parser = XMLReaderFactory.createXMLReader(
			"org.apache.xerces.parsers.SAXParser");

		parser.setFeature("http://xml.org/sax/features/validation", true);

		SAXLexical handler = new SAXLexical();
		parser.setContentHandler(handler);
		parser.setProperty("http://xml.org/sax/properties/lexical-handler",
			handler);

		parser.parse(new InputSource(new FileReader(args[0])));
	}
}
